autowisp.processing_steps.lc_detrending_argument_parser module — AutoWISP documentation

# autowisp.processing_steps.lc_detrending_argument_parser module

## Class Inheritance Diagram

Implement shared argument parsing for LC detrending processing steps.

class autowisp.processing_steps.lc_detrending_argument_parser.DetrendDatasetIter(argument)

  Bases: `object`

  Iterate over the detrending datasets specified in a cmdline argument.

  __init__(argument)

    Set up the iterator for the given argument.

  __next__()

    Return the next dataset specification.

class autowisp.processing_steps.lc_detrending_argument_parser.LCDetrendingArgumentParser(mode, description, *, add_reconstructive=True, convert_to_dict=True, input_type='lc')

  Bases: `ManualStepArgumentParser`

  Boiler plate handling of LC detrending command line arguments.

  __init__(mode, description, *, add_reconstructive=True, convert_to_dict=True, input_type='lc')

    Initialize the parser with options common to all LC detrending steps.

    Parameters:

      ManualStepArgumentParser.__init__(). (See)

    Returns:

      None

  static _add_epd_arguments(parser)

    Add parameters required for EPD only.

  static _add_tfa_arguments(parser)

    Add parameters required for TFA only.

  static add_transit_parameters(parser, *, timing=True, duration=True, geometry='', limb_darkening=False, fit_flags=False)

    Add command line parameters to the current parser to specify a transit.

    Parameters:

      - timing (bool) – Should arguments specifying the timing of the transit be included, i.e. period, ephemerides, duration?

      - duration (bool) – Sholud a potentially redundant argument for transit duration be added?

      - geometry (bool or str) –

        Should arguments specifying the geometry of the transit be included. If the value converts to False, nothing is included. Otherwise this argument should be either:

        > - ’circular’: i.e. include radius ratio, inclination, and semimajor axis.

        > - ’eccentric’: i.e. in additition to the above, include eccentricity and argument of periastron.

      - limb_darkening (bool) – Should arguments for specifying the stellar limb-darkening be included?

    Returns:

      None

autowisp.processing_steps.lc_detrending_argument_parser._parse_fit_datasets(argument)

  Parse the fit datasets argument (see help for details).

autowisp.processing_steps.lc_detrending_argument_parser._parse_lc_variables(argument)

  Parse the EPD variables command line argument (see help for details).

autowisp.processing_steps.lc_detrending_argument_parser._parse_substitutions(substitutions_str_iter)

  Generator of all possible combination of substitutions.

autowisp.processing_steps.lc_detrending_argument_parser._split_delimited_string(argument, separator)

  Split the detrending dataset argument at ;, handling ;;.